- The HTML representation of all scikit-learn estimators
  inheriting from :class:`base.BaseEstimator` now includes a table
  displaying their fitted :term:`attributes`. These are all the public
  estimator attributes that are computed during the call to :term:`fit`
  with a name that ends with an underscore.
  By :user:`Dea María Léon <DeaMariaLeon>`,
  :user:`Jérémie du Boisberranger <jeremiedbb>`,
  :user:`Olivier Grisel <ogrisel>`,
  :user:`Guillaume Lemaitre <glemaitre>`,
  :user:`Antoine Baker <antoinebaker>`.
